==> spring-integration-sftp-2.0.5.RELEASE-sources.jar: org/springframework/integration/sftp/inbound/SftpInboundFileSynchronizer.java <==
/*
 * Copyright 2002-2010 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.integration.sftp.inbound;

import org.springframework.integration.file.remote.session.SessionFactory;
import org.springframework.integration.file.remote.synchronizer.AbstractInboundFileSynchronizer;

import com.jcraft.jsch.ChannelSftp.LsEntry;

/**
 * Handles the synchronization between a remote SFTP directory and a local mount.
 *
 * @author Josh Long
 * @author Oleg Zhurakousky
 * @author Mark Fisher
 * @since 2.0
 */
public class SftpInboundFileSynchronizer extends AbstractInboundFileSynchronizer<LsEntry> {

	public SftpInboundFileSynchronizer(SessionFactory sessionFactory) {
		super(sessionFactory);
	}


	@Override
	protected boolean isFile(LsEntry file) {
		return (file != null && file.getAttrs() != null && !file.getAttrs().isDir() && !file.getAttrs().isLink());
	}

	@Override
	protected String getFilename(LsEntry file) {
		return (file != null ? file.getFilename() : null);
	}

}

==> spring-integration-sftp-2.1.4.RELEASE-sources.jar: org/springframework/integration/sftp/inbound/SftpInboundFileSynchronizer.java <==
/*
 * Copyright 2002-2010 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.integration.sftp.inbound;

import org.springframework.integration.file.remote.session.SessionFactory;
import org.springframework.integration.file.remote.synchronizer.AbstractInboundFileSynchronizer;

import com.jcraft.jsch.ChannelSftp.LsEntry;

/**
 * Handles the synchronization between a remote SFTP directory and a local mount.
 *
 * @author Josh Long
 * @author Oleg Zhurakousky
 * @author Mark Fisher
 * @since 2.0
 */
public class SftpInboundFileSynchronizer extends AbstractInboundFileSynchronizer<LsEntry> {

	public SftpInboundFileSynchronizer(SessionFactory<LsEntry> sessionFactory) {
		super(sessionFactory);
	}


	@Override
	protected boolean isFile(LsEntry file) {
		return (file != null && file.getAttrs() != null && !file.getAttrs().isDir() && !file.getAttrs().isLink());
	}

	@Override
	protected String getFilename(LsEntry file) {
		return (file != null ? file.getFilename() : null);
	}

}
